@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010 German A. Arias <german@xelalug.org>
+   Copyright (C) 2009, 2010, 2012 German A. Arias <german@xelalug.org>
 
    This file is part of FísicaLab application
 
@@ -19,21 +19,24 @@
 */
 
 #import <AppKit/AppKit.h>
-#import <math.h>
 
 @interface MIPizarra : NSView
 {
   id informacion;
-  int codigoObjeto, objetos, conteo ;
+  int codigoObjeto, objetos, conteo;
+  NSUInteger width, height;
   BOOL newObjeto ;
   BOOL moveObjeto ;
   NSImage *imagenIcono ;
+  NSBezierPath *selectedCell;
 }
 - (void) nuevoObjeto: (id)sender;
 - (void) calcular: (id)sender;
 - (void) limpiar: (id)sender;
 - (void)clicCell: (id) sender;
 - (int) codigo: (id)sender;
+- (NSUInteger) chalkboardWidth;
+- (NSUInteger) chalkboardHeight;
 - (void) controlCursor: (id)sender;
 
 @end
