@@ -1,5 +1,5 @@
 /* 
-   Copyright (C) 2009, 2010, 2011 German A. Arias <german@xelalug.org>
+   Copyright (C) 2009, 2010, 2011, 2012 German A. Arias <german@xelalug.org>
 
    This file is part of FísicaLab application
 
@@ -18,23 +18,12 @@
    Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
 */
 
-#import <stdlib.h>
-#import <stdio.h>
-#import <math.h>
-#import <gsl/gsl_vector.h>
-#import <gsl/gsl_multiroots.h>
-#import <gsl/gsl_rng.h>
-#import <AppKit/AppKit.h>
+#import "FLSolverWithCells.h"
 
-@interface dinamicaPuntual : NSObject
+@interface dinamicaPuntual : FLSolverWithCells
 {
-  id dinamicaPuntInfo;
-  int sistema;
   BOOL mensajeFr ;
-  NSArray *ordenObjetos, *conversiones, *errores;
+  NSArray *errores;
 }
-- (void) setSistema: (int)eleccion;
-- (void) setVisor: (id)visor;
-- (void) celdas: (NSArray *)pizarra;
 - (void) crearEcuaciones: (NSMutableDictionary *)lista;
 @end
